==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   emails.lang.inc.php 2018-06-07
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'bulk_delete_selected'                       => 'Löschen',
	'bulk_send_selected'                         => 'Senden',
	'delete_old_attachments'                     => 'Alte Anhänge löschen',
	'delete_old_emails'                          => 'Alte E-Mails löschen',
	'email'                                      => 'E-Mail',
	'emails'                                     => 'E-Mails',
	'email_html'                                 => 'HTML',
	'email_pending'                              => 'Nicht gesendet',
	'email_plain'                                => 'Klartext',
	'email_recipient'                            => 'Empfänger',
	'email_reply_to'                             => 'Antwort an',
	'email_sender'                               => 'Absender',
	'email_sent'                                 => 'Gesendet',
	'email_subject'                              => 'Betreff',
	'handle_attachments'                         => 'Alte Anhänge löschen',
	'handle_old_emails'                          => 'Alte E-Mails löschen',
	'message_attachment_could_not_be_found'      => 'E-Mail konnte nicht gesendet werden, da folgende Anhänge fehlen:',
	'message_delete_old_attachments_description' => 'Bitte wählen sie ein Datum, bis zu welchem die alten Anhänge gelöscht werden sollen.',
	'message_delete_old_attachments_success'     => 'Die Anhänge wurden erfolgreich gelöscht!',
	'message_delete_old_emails_description'      => 'Bitte wählen sie ein Datum, bis zu welchem die alten E-Mails gelöscht werden sollen.',
	'message_delete_old_emails_notice'           => 'Bitte beachten Sie vom dem Löschen von E-Mails, die gesetzlichen Aufbewahrungsfristen für geschäftliche Unterlagen!',
	'message_delete_old_emails_success'          => 'Die E-Mails wurden erfolgreich gelöscht!',
	'message_download_attachment_error'          => 'Der Anhang konnte nicht gefunden werden.',
	'message_remove_attachment_error'            => 'Die Datei konnte nicht entfernt werden. Der Server reagiert mit der folgenden Meldung: ',
	'message_upload_attachment_error'            => 'Die Datei konnte nicht hochgeladen werden. Der Server reagiert mit der folgenden Meldung: ',
	'modal_attachments'                          => 'Anhänge',
	'modal_contact_email'                        => 'E-Mail',
	'modal_contact_name'                         => 'Name',
	'modal_contact_type'                         => 'Typ',
	'modal_details'                              => 'Details',
	'modal_path'                                 => 'Pfad',
	'modal_upload_attachment'                    => 'Anhang hochladen',
	'name'                                       => 'Name',
	'prompt_delete_collection'                   => 'Wollen Sie die ausgewählten E-Mails löschen?',
	'prompt_delete_email'                        => 'Möchten Sie diese E-Mail löschen?',
	'prompt_delete_old_attachments'              => 'Möchten Sie die Anhänge bis zum ausgewählten Datum löschen?',
	'prompt_delete_old_emails'                   => 'Möchten Sie die E-Mails bis zum ausgewählten Datum löschen?',
	'prompt_send_collection'                     => 'Wollen Sie die ausgewählten E-Mails senden?',
	'prompt_send_email'                          => 'Möchten Sie diese E-Mail senden?',
	'removal_date'                               => 'Entfernung Datum',
	'table_actions'                              => 'Aktionen',
	'table_creation'                             => 'Erstellt',
	'table_status'                               => 'Status'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   emails.lang.inc.php 2018-06-07
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'bulk_delete_selected'                       => 'Löschen',
	'bulk_send_selected'                         => 'Senden',
	'delete_old_attachments'                     => 'Alte Anhänge löschen',
	'delete_old_emails'                          => 'Alte E-Mails löschen',
	'email'                                      => 'E-Mail',
	'emails'                                     => 'E-Mails',
	'email_html'                                 => 'HTML',
	'email_pending'                              => 'Nicht gesendet',
	'email_plain'                                => 'Klartext',
	'email_recipient'                            => 'Empfänger',
	'email_reply_to'                             => 'Antwort an',
	'email_sender'                               => 'Absender',
	'email_sent'                                 => 'Gesendet',
	'email_subject'                              => 'Betreff',
	'handle_attachments'                         => 'Alte Anhänge löschen',
	'handle_old_emails'                          => 'Alte E-Mails löschen',
	'message_attachment_could_not_be_found'      => 'E-Mail konnte nicht gesendet werden, da folgende Anhänge fehlen:',
	'message_delete_old_attachments_description' => 'Bitte wähle ein Datum, bis zu welchem die alten Anhänge gelöscht werden sollen.',
	'message_delete_old_attachments_success'     => 'Die Anhänge wurden erfolgreich gelöscht!',
	'message_delete_old_emails_description'      => 'Bitte wähle ein Datum, bis zu welchem die alten E-Mails gelöscht werden sollen.',
	'message_delete_old_emails_notice'           => 'Bitte beachte vor dem Löschen von E-Mails die gesetzlichen Aufbewahrungsfristen für geschäftliche Unterlagen!',
	'message_delete_old_emails_success'          => 'Die E-Mails wurden erfolgreich gelöscht!',
	'message_download_attachment_error'          => 'Der Anhang konnte nicht gefunden werden.',
	'message_remove_attachment_error'            => 'Die Datei konnte nicht entfernt werden. Der Server reagiert mit der folgenden Meldung: ',
	'message_upload_attachment_error'            => 'Die Datei konnte nicht hochgeladen werden. Der Server reagiert mit der folgenden Meldung: ',
	'modal_attachments'                          => 'Anhänge',
	'modal_contact_email'                        => 'E-Mail',
	'modal_contact_name'                         => 'Name',
	'modal_contact_type'                         => 'Typ',
	'modal_details'                              => 'Details',
	'modal_path'                                 => 'Pfad',
	'modal_upload_attachment'                    => 'Anhang hochladen',
	'name'                                       => 'Name',
	'prompt_delete_collection'                   => 'Möchtest du die ausgewählten E-Mails löschen?',
	'prompt_delete_email'                        => 'Möchtest du diese E-Mail löschen?',
	'prompt_delete_old_attachments'              => 'Möchtest du die Anhänge bis zum ausgewählten Datum löschen?',
	'prompt_delete_old_emails'                   => 'Möchtest du die E-Mails bis zum ausgewählten Datum löschen?',
	'prompt_send_collection'                     => 'Möchtest du die ausgewählten E-Mails senden?',
	'prompt_send_email'                          => 'Möchtest du diese E-Mail senden?',
	'removal_date'                               => 'Entfernung Datum',
	'table_actions'                              => 'Aktionen',
	'table_creation'                             => 'Erstellt',
	'table_status'                               => 'Status'
);
